@@ -2,6 +2,9 @@ from typing import List, Tuple
 
 from pyfileconf.io.file.load.lazy.base.impassign import ImportAssignmentLazyLoader
 from pyfileconf.config.logic.load import _split_lines_into_import_and_assignment
+from pyfileconf.pmcontext.actions import PyfileconfActions
+from pyfileconf.pmcontext.tracing import StackTracker
+
 
 class ConfigFileLoader(ImportAssignmentLazyLoader):
 
@@ -9,11 +12,12 @@ class ConfigFileLoader(ImportAssignmentLazyLoader):
         # Get ast, body, imports, assigns
         super().register()
 
-        # Extract assignment portion of body
-        self._file_body_to_assignment_body()
+        with StackTracker(file_path=self.filepath, action=PyfileconfActions.LOAD_FILE_AST):
+            # Extract assignment portion of body
+            self._file_body_to_assignment_body()
 
-        # Parse assigns into config dict
-        config_dict, annotation_dict = self.assigns.to_default_dict_and_annotation_dict()
+            # Parse assigns into config dict
+            config_dict, annotation_dict = self.assigns.to_default_dict_and_annotation_dict()
 
         return config_dict, annotation_dict
 
