@@ -6,6 +6,8 @@ from typing import Any, Dict, Sequence, List, Tuple, TYPE_CHECKING, Iterable, Op
 if TYPE_CHECKING:
     from pyfileconf.iterate import IterativeRunner
     from pyfileconf.main import PipelineManager
+    from pyfileconf.basemodels.config import ConfigBase
+    from pyfileconf.config.models.manager import ConfigManager
 
 from pyfileconf.plugin.impl import hookimpl
 from pyfileconf.plugin import manager
@@ -48,18 +50,11 @@ def pyfileconf_iter_update_for_case(
     else:
         updated_confs = case
 
-    use_confs: List[Dict[str, Any]] = []
-    for conf in updated_confs:
-        conf = {**conf, 'pyfileconf_persist': False}
-        use_confs.append(conf)
-
     bu = BatchUpdater(
         base_section_path_str=runner.base_section_path_str,
         strip_manager_from_iv=runner.strip_manager_from_iv,
     )
-    sp_strs = [conf['section_path_str'] for conf in use_confs]
-    bu.reset(sp_strs)
-    bu.update(use_confs)
+    bu.update(updated_confs)
 
 
 @hookimpl
@@ -67,3 +62,28 @@ def pyfileconf_pre_update_batch(
     pm: "PipelineManager", updates: Iterable[dict],
 ) -> Iterable[dict]:
     return updates
+
+
+@hookimpl
+def pyfileconf_post_config_changed(
+    manager: 'ConfigManager',
+    new_config: 'ConfigBase',
+    updates: Dict[str, Any],
+    section_path_str: str,
+) -> None:
+    """
+    Refresh dependent configs after config change
+
+    :param manager: the config manager in which the changing
+        config resides
+    :param new_config: the config after any changes
+    :param updates: the updates which were made to the config
+    :param section_path_str: the section path string which can
+        be used to look up the config
+    :return: None
+
+    :Notes:
+
+        Only called if the action actually modified the config
+    """
+    manager.refresh_dependent_configs(section_path_str)
\ No newline at end of file
